clear
set mem 500m
set more off
capture log close


cd "[insert model director]"
log using "Opex econometrics.log", replace

************************************************************************************************************************************************************
*This do file provides the analysis used to determine the econometric models for network and non-network opex used in the 2012 reset of EDB starting prices*
************************************************************************************************************************************************************

*The remainder of the do file:
	* cleans the data generates new variables for the analysis
	* undertakes exploratory analysis to understand the relationship between different measures of scale and opex
	* estimates a robust econometric model for network opex
	* estimates a robust econometric model for non-network opex

*Note: This analysis used revised length data provided by EDBs in submissions on the draft decision	

***************************************
*Clean data and generate new variables*
***************************************
use "EDB data.dta"

*REPLACE MISSING OH DATA
replace oh = circuit_length_total - ug if oh == .

*REPLACE TYPO FOR POWERCO
replace electricity_supplied = electricity_supplied*1000 if year == 2004 & edb == "Powerco"

*EXCLUDE VARIABLES NOT NEEDED
drop  general_admin_ovhead management_operations routine_prevent refurb_renewal fault_ems passthrough ac_loss_rebates other  nsfa_capex sfa_capex

*EXCLUDE VECTOR AND WELLINGTON DATA FROM 2009 AS DE-MERGER OCCURED MID YEAR. THEREFORE THE RELATIONSHIP BETWEEN EXPENDITURE AND SCALE
*IS LIKELY YO BE DISTORTED
drop if edb == "Vector" & year == 2009 | edb == "Wellington" & year == 2009

*EXCLUDE ORION DATA FROM 2011 (2010 DATA ADJUSTED BY CPI)
drop if edb == "Orion" & year == 2011

*GENERATE NEW VARIBALES:
gen icp_km = icp_total/circuit_length_total
label var icp_km "Number of connection points per km of circuit"

gen energy_density =  electricity_supplied/icp_total
label var energy_density "Electricity supplied per connection point"

gen pc_ug = ug/circuit_length_total
label var pc_ug "% of circuit length underground"

label var icp_total "Number of connection points"

gen exempt = 0
label var exempt "indicates exempt EDB"
replace exempt = 1 if edb == "Buller" | edb == "Counties" | edb == "Electra" | edb == "Mainpower" | edb == "Marlborough" ///
| edb == "Waitaki" | edb == "Northpower" | edb == "Scanpower" | edb == "TPCL" | edb == "Waipa" | edb == "WEL" | edb == "Westpower"


*GENERATE LOGS:
foreach var in opex direct indirect circuit_length_total  electricity_entering electricity_supplied icp_total {
	gen l`var' = ln(`var')
}



*

*GENERATE VARIABLES TO TEST WHETHER COEFFICIENT DIFFER FOR EXEMPT EDBS
gen lcircuit_exempt 	= lcircuit_length_total*exempt
gen licp_exempt 		= licp_total*exempt
gen lelectricity_exempt = lelectricity_supplied*exempt
gen icp_km_exempt		= icp_km*exempt

*GENERATE VARIABLES TO TEST WHETHER COEFFICIENT DIFFERS BY YEAR
foreach year in 2008 2009 2010 2011 {
	gen y`year' = 0
	replace y`year' = 1 if year == `year'
*include interaction terms
	gen lcircuit_`year' 	= lcircuit_length_total*y`year'
	gen licp_`year' 		= licp_total*y`year'
	gen lelectricity_`year' = lelectricity_supplied*y`year'
	gen icp_km_`year' 	= icp_km*y`year'
	gen lcircuit_exempt_`year' = lcircuit_exempt*y`year'
}

*


*Create variables for Roy-Zellner poolability test

gen Yyear_1 = 1 if year == 2010
replace Yyear_1 = 0 if year!=2010

gen Yyear_2 = 1 if year == 2011
replace Yyear_2 = 0 if year!=2011

 
foreach var of varlist lcircuit_length_total licp_total   {
	foreach num of numlist 1(1)2{
		gen `var'_`num'=`var'*Yyear_`num'
}
}

*

*EXCLUDE NETWORK AND NON-NETWORK OPEX PRIOR TO 2010 AS NOT ALL EDBS REPORT AND DATA APPEARS INCONSISTENT
replace direct 		= . if year < 2010
replace indirect 	= . if year < 2010
replace direct 		= . if direct == 0
replace indirect 	= . if indirect == 0
replace ldirect		= . if year < 2010
replace lindirect 	= . if year < 2010

*DECLARE AS PANEL DATA
tsset id  year, yearly



******************************
*Exploratory analysis of data*
******************************

*CORRELATION MATRIX:
corr direct indirect circuit_length_total icp_total electricity_supplied icp_km energy_density pc_ug pc_rugged 

*SCATTER PLOTS FOR REPORT

scatter ldirect lcircuit_length_total if year > 2009, saving(g1, replace) mcolor("55 96 145")  graphregion(color("white") /// 
icolor("white") lcolor("white") fcolor("white")) plotregion(icolor("white") margin(zero)) ///
xtitle("Log of total circuit length") ytitle("Log of network opex") legend(off) ylabel(, nogrid)  yscale(r(5 11)) ylabel(#7, angle(horizontal))
scatter ldirect licp_total if year > 2009, saving(g2, replace) mcolor("55 96 145")  graphregion(color("white") /// 
icolor("white") lcolor("white") fcolor("white")) plotregion(icolor("white") margin(zero)) ///
xtitle("Log of total ICPs") ytitle("Log of network opex") legend(off) ylabel(, nogrid)  yscale(r(5 11)) ylabel(#7, angle(horizontal))
scatter ldirect lelectricity_supplied if year > 2009, saving(g3, replace) mcolor("55 96 145")  graphregion(color("white") /// 
icolor("white") lcolor("white") fcolor("white")) plotregion(icolor("white") margin(zero)) ///
xtitle("Log of electricity supplied to ICPs") ytitle("Log of network opex") legend(off) ylabel(, nogrid angle(horizontal))  yscale(r(5 11)) ylabel(#7) xscale(r(3 9)) xlabel(#7)
graph combine g1.gph g2.gph g3.gph, graphregion(color("white") icolor("white") lcolor("white") fcolor("white")) plotregion(icolor("white") margin(zero))  


scatter lindirect lcircuit_length_total if year > 2009, saving(g1, replace) mcolor("55 96 145")  graphregion(color("white") /// 
icolor("white") lcolor("white") fcolor("white")) plotregion(icolor("white") margin(zero)) ///
xtitle("Log of total circuit length") ytitle("Log of non-network opex") legend(off) ylabel(, nogrid angle(horizontal))  yscale(r(6 11)) ylabel(#6)
scatter lindirect licp_total if year > 2009, saving(g2, replace) mcolor("55 96 145")  graphregion(color("white") /// 
icolor("white") lcolor("white") fcolor("white")) plotregion(icolor("white") margin(zero)) ///
xtitle("Log of total ICPs") ytitle("Log of non-network opex") legend(off) ylabel(, nogrid angle(horizontal))  yscale(r(6 11)) ylabel(#6)
scatter lindirect lelectricity_supplied if year > 2009, saving(g3, replace) mcolor("55 96 145")  graphregion(color("white") /// 
icolor("white") lcolor("white") fcolor("white")) plotregion(icolor("white") margin(zero)) ///
xtitle("Log of electricity supplied to ICPs") ytitle("Log of non-network opex") legend(off) ylabel(, nogrid angle(horizontal))  yscale(r(6 11)) ylabel(#6) xscale(r(3 9)) xlabel(#7)
graph combine g1.gph g2.gph g3.gph, graphregion(color("white") icolor("white") lcolor("white") fcolor("white")) plotregion(icolor("white") margin(zero))  


**************
*Outlier code*
**************

*This code is used as part of robustness checks of the econometric model

program drop _all
program define test_outlier
predict yhattt, xb
predict e, residuals
predict lev, leverage
predict dfits, dfits
predict wd, welsch
predict cooksd, cooksd

*e(N) = sample size, k = no. of independent variables including constant
gen k = e(df_m) + 1 

list edb dfits if abs(dfits)>2*sqrt(k/e(N))
*By DFITS-attempts to summarize the information in the leverage versus residual-squared plot into a single statistic

list edb cooksd if abs(cooksd)>4/e(N)
*By Cook's Distance is function of DFITS, is a metric for deciding whether a particular point alone affects regression estimates much

list edb wd if abs(wd)>3*sqrt(k)
*By Welsch's Distance is function of DFITS

list edb lev if lev>((2*k)/e(N))
*By Leverage refers to the influence of observations on the estimated relationship and is the most common statistic employed to identify such observations

gen g1=1 if abs(dfits)>2*sqrt(k/e(N)) 
gen dfits_outlier_stat=abs(dfits)
quietly scatter e yhattt , msize(small) scale(0) || scatter e yhattt if g1==1, mcolor(red) ///
msymbol() msize(small) yline(0) || scatter e yhattt if g1==1, mcolor(red) msymbol() ///
msize(small) yline(0) mlabel(edb) mlabcolor(blue) ///
saving(DFITS, replace)

gen g2=1 if abs(cooksd)>4/e(N)
gen cooksd_outlier_stat=abs(cooksd)
quietly scatter e yhattt, msize(small) scale(0) || scatter e yhattt if g2==1, ///
mcolor(red) msymbol() msize(small) yline(0) || scatter e yhattt if g2==1, mcolor(red) ///
msymbol() msize(small) yline(0) mlabel(edb) mlabcolor(blue) ///
saving(Cooks_distance, replace)

gen g3=1 if abs(wd)>3*sqrt(k)
gen wd_outlier_stat=abs(wd)
quietly scatter e yhattt, msize(small) scale(0) || scatter e yhattt if g3==1, mcolor(red) ///
msymbol() msize(small) yline(0) || scatter e yhattt if g3==1, mcolor(red) ///
msymbol() msize(small) yline(0) mlabel(edb) mlabcolor(blue) ///
saving(Welsch_distance, replace)

gen g4=1 if lev>((2*k)/e(N))
gen lev_outlier_stat=abs(lev)
quietly scatter e yhattt, msize(small) scale(0) || scatter e yhattt if g4==1, mcolor(red) ///
msymbol() msize(small) yline(0) || scatter e yhattt if g4==1, mcolor(red) ///
msymbol() msize(small) yline(0) mlabel(edb) mlabcolor(blue) ///
saving(leverage, replace)

drop yhattt e lev dfits wd cooksd k 

end




**********************************
*Identify model for network opex * 
**********************************


*RUN DIFFERENT POTENTIAL ECONOMETRIC MODELS
reg ldirect lcircuit_length_total if year > 2009, robust
ereturn	list r2_a 
estat ic

reg ldirect lcircuit_length_total icp_km if year > 2009, robust
ereturn	list r2_a 
estat ic

reg ldirect lcircuit_length_total icp_km pc_ug if year > 2009, robust
ereturn	list r2_a 
estat ic

reg ldirect lcircuit_length_total icp_km pc_rugged if year > 2009, robust
ereturn	list r2_a 
estat ic

reg ldirect lcircuit_length_total licp_total if year > 2009 , robust
ereturn	list r2_a 
estat ic

reg ldirect lcircuit_length_total licp_total icp_km if year > 2009 , robust
ereturn	list r2_a 
estat ic

reg ldirect lcircuit_length_total licp_total  lelectricity_supplied if year > 2009 , robust
ereturn	list r2_a 
estat ic

reg ldirect lcircuit_length_total licp_total energy_density if year > 2009 , robust
ereturn	list r2_a 
estat ic


*OUTLIER AND DIAGNOSTIC TESTS OF PREFERRED MODEL


*Outlier testing 
reg ldirect lcircuit_length_total licp_total if year > 2009
test_outlier
foreach var in g1 g2 g3 g4 {
	replace `var' = 0 if `var' == .
	replace `var' = 0 if year < 2010	/*data prior to 2010 not included in model*/
}
gen sum_outlier = g1 + g2 + g3 + g4
label var sum_outlier "Indicates if observation a potential outlier"
list edb year sum_outlier if sum_outlier > 1
drop g1 g2 g3 g4  dfits_outlier_stat cooksd_outlier_stat wd_outlier_stat lev_outlier_stat sum_outlier 
*-> Nelson identified as outlier in 2011 as it exceeds more than 3 critical values. While TLC in 2011 isn't identified as a statistical outlier according to our criteria
* the large jump in line lenghth (from 4490.9 in 2010 to 5001 in 2011) is unusual and we therefore exclude it as well.

gen outlier = 0
replace outlier = 1 if edb == "Nelson" & year == 2011  | edb == "TLC" & year==2011
label var outlier "Outlier dummy variable (Nelson and TLC in 2011)"

*Residuals, AV plots and omitted variables
reg ldirect lcircuit_length_total licp_total if year > 2009 & outlier == 0
avplots
ovtest
*Accept the null of no misspecification
imtest 
*Reject the null of homoscedastic errors (Cameron & Trivedi's decomp of IM test)
hettest
*Reject the null of homoscedastic errors

*Normality of residuals;
reg ldirect lcircuit_length_total licp_total if year > 2009 & outlier == 0
predict res if outlier == 0, resid
swilk res
histogram res, normal bin(20)
drop res

*Test whether coefficients differ for exempt edbs (similar to Chow test)
reg ldirect lcircuit_length_total lcircuit_exempt licp_total licp_exempt exempt if outlier == 0 , robust
test lcircuit_exempt licp_exempt exempt


*Test between logs and levels (Davidson-Mckinnon test)
reg ldirect lcircuit_length_total licp_total if year > 2009 & outlier == 0, robust
predict res, res
reg direct circuit_length_total icp_total res, robust
test res
drop res
*->coefficient on residual is statistically significant, indicating log model is appropriate

*Quantile regression; note that seed is not set so t test statistics differ somewhat from run to run
sqreg ldirect lcircuit_length_total licp_total if year > 2009 & outlier == 0, quantile(0.25 0.5 0.75) rep(500)
	test [q25]lcircuit_length_total = [q50]lcircuit_length_total
	test [q25]lcircuit_length_total = [q75]lcircuit_length_total
	test [q50]lcircuit_length_total = [q75]lcircuit_length_total
	test [q25]licp_total = [q50]licp_total
	test [q25]licp_total = [q75]licp_total
	test [q50]licp_total = [q75]licp_total
*->  ACCEPT null hypothesis that coefficients are equal across ALL quantiles

*Test whether pooled panel model is appropriate:
reg ldirect lcircuit_length_total licp_total y2010 lcircuit_2010 licp_2010 if year > 2009 & outlier == 0, robust
test  lcircuit_2010 licp_2010
*->pooled panel model is appropriate as we cannot reject the null hypothesis that the coefficients each year differ from zero 


*Test predictive power of model
reg ldirect lcircuit_length_total  if year > 2009 & outlier == 0, robust
predict yhat, xb
scatter ldirect yhat if exempt == 0, mlabel(edb) xscale(r(6(1)11))  xlabel(#6) xtitle("ln(network opex)") ///
ytitle("predicted ln(network opex)") graphregion(color("white") icolor("white") lcolor("white") fcolor("white")) plotregion(icolor("white") margin(zero)) ///
legend(off) ylabel(, nogrid) ||lfit ldirect yhat, lcolor(black)
drop yhat	
*Note: Below line indicates model under-predicts opex. Above line indicates model over-predicts opex


*DIAGNOSTIC TESTS ON MODEL PROPOSED BY CASTALIA: NETWORK LENGTH + ICP/KM

*Residuals, AV plots and omitted variables

reg ldirect lcircuit_length_total icp_km if year > 2009 
test_outlier
foreach var in g1 g2 g3 g4 {
	replace `var' = 0 if `var' == .
	replace `var' = 0 if year < 2010	/*data prior to 2010 not included in model*/
}
gen sum_outlier = g1 + g2 + g3 + g4
label var sum_outlier "Indicates if observation a potential outlier"
list edb year sum_outlier if sum_outlier > 1
drop g1 g2 g3 g4  dfits_outlier_stat cooksd_outlier_stat wd_outlier_stat lev_outlier_stat sum_outlier 
*-> Nelson identified as outlier in 2011 as it exceeds more than 3 critical values. While TLC in 2011 isn't identified as a statistical outlier according to our criteria
* the large jump in line lenghth (from 4490.9 in 2010 to 5001 in 2011) is unusual and we therefore exclude it as well.

reg ldirect lcircuit_length_total icp_km if year > 2009 & outlier == 0
*Residuals, AV plots and omitted variables
reg ldirect lcircuit_length_total licp_total if year > 2009 & outlier == 0
avplots
ovtest
*Accept the null of no misspecification
imtest 
*Reject the null of homoscedastic errors (Cameron & Trivedi's decomp of IM test)
hettest
*Reject the null of homoscedastic errors



*Normality of residuals;
reg ldirect lcircuit_length_total icp_km if year > 2009 & outlier == 0
predict res if outlier == 0, resid
histogram res, normal bin(20)
swilk res
drop res

*Test whether coefficients differ for exempt edbs (similar to Chow test)
reg ldirect lcircuit_length_total lcircuit_exempt icp_km icp_km_exempt exempt if outlier == 0 , robust
test lcircuit_exempt  icp_km_exempt exempt		
*Accept the null that coefficients do not differ between exempt and non-exempt electricity distributors

		
*Quantile regression; note that seed is not set so t test statistics differ somewhat from run to run
sqreg ldirect lcircuit_length_total icp_km if year > 2009 & outlier == 0, quantile(0.25 0.5 0.75) rep(500) 
	test [q25]lcircuit_length_total = [q50]lcircuit_length_total
	test [q25]lcircuit_length_total = [q75]lcircuit_length_total
	test [q50]lcircuit_length_total = [q75]lcircuit_length_total
	test [q25]icp_km = [q50]icp_km
	test [q25]icp_km = [q75]icp_km
	test [q50]icp_km = [q75]icp_km
*-> ACCEPT null hypothesis that coefficients are equal across ALL quantiles		
	
*Chow test whether pooled panel model is appropriate:
reg ldirect lcircuit_length_total icp_km y2010 lcircuit_2010 icp_km_2010 if year > 2009 & outlier == 0, robust
test  lcircuit_2010 icp_km_2010
*->pooled panel model is appropriate as we cannot reject the null hypothesis that the coefficients each year differ from zero 		
* Network opex model - Roy-Zellner test of poolability 
xtreg ldirect lcircuit_length_total_*  licp_total_* if year > 2009 & outlier==0, re i(year)
test (lcircuit_length_total_1 = lcircuit_length_total_2) (licp_total_1 = licp_total_2)
*->conclude: we can pool the data across time

*--> concldue that Castalia's model statistical robustness is similar to preferred model
	
	
*Visually show the predictive power of model of different models

*Preferred model
reg ldirect lcircuit_length_total licp_total if year > 2009 & outlier == 0, robust
predict yhat, xb
scatter ldirect yhat if exempt == 0, saving(g1, replace) ///
mlabel() xscale(r(5(1)11)) yscale(r(5(1)11)) xlabel(#7) ylabel(#7, angle(horizontal)) xtitle("log of network opex") ///
ytitle("Predicted value - Decision") graphregion(color("white") icolor("white") lcolor("white") fcolor("white")) plotregion(icolor("white") margin(zero)) ///
legend(off) ylabel(, nogrid) || lfit ldirect yhat, lcolor(black)
drop yhat	
*proposed by Castalia
reg ldirect lcircuit_length_total icp_km if year > 2009 & outlier == 0, robust
predict yhat, xb
scatter ldirect yhat if exempt == 0, saving(g21, replace) ///
mlabel() xscale(r(5(1)11)) yscale(r(5(1)11)) xlabel(#7)ylabel(#7, angle(horizontal)) xtitle("log of network opex") ///
ytitle("Predicted value - Castalia") graphregion(color("white") icolor("white") lcolor("white") fcolor("white")) plotregion(icolor("white") margin(zero)) ///
legend(off) ylabel(, nogrid) || lfit ldirect yhat, lcolor(black)
drop yhat	
*proposed by CEG
reg ldirect lcircuit_length_total lelectricity_supplied if year > 2009 & outlier == 0, robust
predict yhat, xb
scatter ldirect yhat if exempt == 0, saving(g22, replace) ///
mlabel() xscale(r(5(1)11)) yscale(r(5(1)11)) xlabel(#7) ylabel(#7, angle(horizontal)) xtitle("log of network opex") ///
ytitle("Predicted value - CEG") graphregion(color("white") icolor("white") lcolor("white") fcolor("white")) plotregion(icolor("white") margin(zero)) ///
legend(off) ylabel(, nogrid) || lfit ldirect yhat, lcolor(black)
drop yhat	
*Draft decision model
reg ldirect lcircuit_length_total  if year > 2009 & outlier == 0, robust
predict yhat, xb
scatter ldirect yhat if exempt == 0, saving(g23, replace) ///
mlabel() xscale(r(5(1)11)) yscale(r(5(1)11)) xlabel(#7) ylabel(#7, angle(horizontal)) xtitle("log of network opex") ///
ytitle("Predicted value - Draft") graphregion(color("white") icolor("white") lcolor("white") fcolor("white")) plotregion(icolor("white") margin(zero)) ///
legend(off) ylabel(, nogrid) || lfit ldirect yhat, lcolor(black)
drop yhat	

graph combine g1.gph g21.gph g22.gph g23.gph, graphregion(color("white") icolor("white") lcolor("white") fcolor("white")) plotregion(icolor("white") margin(zero))  

*Note: Below line indicates model under-predicts opex. Above line indicates model over-predicts opex





**************************************
*Identify  model for non-network opex* 
**************************************

*RUN DIFFERENT POTENTIAL ECONOMETRIC MODELS

reg lindirect lcircuit_length_total lelectricity_supplied icp_km if year > 2009, robust
ereturn	list r2_a 
estat ic

reg lindirect lcircuit_length_total lelectricity_supplied icp_km licp_total if year > 2009, robust
ereturn	list r2_a 
estat ic

reg lindirect lcircuit_length_total lelectricity_supplied licp_total if year > 2009, robust
ereturn	list r2_a 
estat ic


reg lindirect lcircuit_length_total licp_total if year > 2009, robust
ereturn	list r2_a 
estat ic

reg lindirect licp_total if year > 2009, robust
ereturn	list r2_a 
estat ic


*REGRESSION MODEL

reg lindirect lcircuit_length_total lelectricity_supplied icp_km licp_total if year > 2009, robust 
*Result: all variables insignificant except ICPs

*model with just ICPs
reg lindirect licp_total if year > 2009, robust 

*draft decision model
reg lindirect  lcircuit_length_total lelectricity_supplied icp_km if year > 2009 , robust


*model just with ICPs has better explanatory power than draft decision model

*OUTLIER AND DIAGNOSTIC TESTS OF PREFERRED MODEL

*Test for outliers
reg lindirect licp_total if year > 2009
quietly test_outlier

foreach var in g1 g2 g3 g4 {
	replace `var' = 0 if `var' == .
	replace `var' = 0 if year < 2010	/*data prior to 2010 not included in model*/
}
gen sum_outlier = g1 + g2 + g3 + g4
label var sum_outlier "Indicates if observation a potential outlier"
list edb year sum_outlier if sum_outlier > 1
drop g1 g2 g3 g4  dfits_outlier_stat cooksd_outlier_stat wd_outlier_stat lev_outlier_stat sum_outlier 
*->Buller identified as outlier in 2011


*REGRESSION MODEL WITHOUT OUTLIER
gen outlier_nn = 0
replace outlier_nn = 1 if edb == "Buller" & year == 2011
label var outlier_nn "Non-network opex dummy variable (Buller, 2011)"
reg lindirect licp_total if year > 2009 & outlier_nn==0, robust



*Residuals, AV plots and omitted variables

reg lindirect  licp_total if year > 2009 & outlier_nn==0
ovtest
*Accept the null of no misspecification
hettest
*Accept the null of homoscedastic errors 
imtest
*Accept the null of homoscedastic errors (Cameron & Trivedi's decomp of IM test)


*Test normality of residuals
reg lindirect licp_total if year > 2009 & outlier_nn==0, robust 
predict res, resid
histogram res, normal bin(20)
swilk res
drop res
*->Accept the null hypothesis of normally distributed error

*Test whether coefficients differ for exempt edbs (similar to Chow test)
reg lindirect licp_total licp_exempt exempt if year > 2009 & outlier_nn==0, robust
test licp_exempt exempt
*Accept the null that coefficients do not differ between exempt and non-exempt electricity distributors


*Test between logs and levels (Davidson-McKinnon test)
reg lindirect licp_total if year > 2009 & outlier_nn==0, robust
predict res, res
reg indirect icp_total res, robust
test res
drop res
*->coefficient on residual is statistically significant, indicating log model is appropriate


*Quantile regression; note that seed is not set so t test statistics differ somewhat from run to run
sqreg lindirect licp_total if year > 2009 & outlier_nn==0, quantile(0.25 0.5 0.75)  rep(500) 
	test [q25]licp_total = [q50]licp_total
	test [q25]licp_total = [q75]licp_total
	test [q50]licp_total = [q75]licp_total
*-> suggests that cofficients between 25th and 75th quartile may differ	

*Chow test whether pooled panel model is appropriate:
reg lindirect licp_total y2010 licp_2010 if year > 2009 & outlier_nn==0, robust
test  y2010 licp_2010
*->pooled panel model is appropriate as we cannot reject the null hypothesis that the coefficients each year differ from zero 		
*non-network opex model - Roy-Zellner test of poolability 
xtreg lindirect licp_total_* if year > 2009 & outlier_nn==0, re i(year)
test (licp_total_1 = licp_total_2)
*->conclude: we can pool the data across time



		
*Visually show the predictive power of model of different models

*Preferred non network opex model
reg lindirect licp_total if year > 2009 & outlier_nn==0, robust
predict yhat, xb
scatter lindirect yhat if exempt == 0, saving(g3, replace)  ///
mlabel() xscale(r(5(1)11)) yscale(r(5(1)11)) xlabel(#7)  ylabel(#7, angle(horizontal)) xtitle("log of non-network opex") ytitle("Predicted value - Decision") ///
graphregion(color("white") icolor("white") lcolor("white") fcolor("white")) plotregion(icolor("white") margin(zero)) ///
legend(off) ylabel(, nogrid) || lfit lindirect yhat, lcolor(black)
drop yhat
*Draft decision non-network opex model	
reg lindirect  lcircuit_length_total lelectricity_supplied icp_km if year > 2009 & outlier_nn==0, robust
predict yhat, xb
scatter ldirect yhat if exempt == 0, saving(g4, replace)  ///
mlabel() xscale(r(5(1)11))yscale(r(5(1)11))  xlabel(#7) ylabel(#7, angle(horizontal)) xtitle("log of non-network opex")  ///
ytitle("Predicted value - Draft ") graphregion(color("white") icolor("white") lcolor("white") fcolor("white")) plotregion(icolor("white") margin(zero)) ///
legend(off) ylabel(, nogrid) || lfit ldirect yhat, lcolor(black)
drop yhat	

graph combine g3.gph g4.gph, graphregion(color("white") icolor("white") lcolor("white") fcolor("white")) plotregion(icolor("white") margin(zero))  

*-> Below line indicates model under-predicts opex. Above line indicates model over-predicts opex


	
**************************************************************
*Exporting results to Excel  to populate reasons paper tables*
**************************************************************

*Prefered network and non-network opex summary table for reasons paper
eststo clear
*Preferred network opex model excluding Nelson in 2011( (length of circuit, number of ICPs);
eststo: quietly reg ldirect lcircuit_length_total licp_total if year > 2009 & outlier==0, robust
*Preferred non network opex model excluding Buller in 2011 (number of ICPs);
eststo: quietly reg lindirect licp_total if year > 2009 & outlier_nn==0, robust
estout using " network and non network preferred models.xls", cells(b(star fmt(%9.3f))) stats(r2_a  aic bic F N , fmt(%9.2f) )   starlevels(* 0.10 ** 0.05 *** 0.01) replace


*Network opex summary table for reasons paper
eststo clear
*Table with different specifications for non network opex-all exlcuding Nelson and The Lines Company in 2011
*Preferred model (length of circuit, number of ICPs);
eststo: quietly reg ldirect lcircuit_length_total licp_total if year > 2009 & outlier==0, robust
*Specification proposed by Castalia -length and density
eststo: quietly reg ldirect lcircuit_length_total icp_km if year > 2009 & outlier==0, robust
*Proposed by CEG + energy + length of circuit;
eststo: quietly reg ldirect lcircuit_length_total lelectricity_supplied if year > 2009 & outlier==0, robust /*Draft decision preferred model*/
* Energy delivered + length of circuit+ number of connections;
eststo: quietly reg ldirect lcircuit_length_total lelectricity_supplied licp_total icp_km if year > 2009 & outlier==0, robust /*Draft decision preferred model*/
* Energy delivered+ length of circuit+ number of connections+ density;
eststo: quietly reg ldirect lcircuit_length_total lelectricity_supplied licp_total if year > 2009 & outlier==0, robust /*Draft decision preferred model*/
*Draft decision model (length of circuit);
eststo: quietly reg ldirect  lcircuit_length_total    if year > 2009 & outlier==0, robust /*Draft decision preferred model*/
estout using "network opex decision.xls", cells(b(star fmt(%9.3f))) stats(r2_a  aic bic F N , fmt(%9.2f) )   starlevels(* 0.10 ** 0.05 *** 0.01) replace

*  Non-network opex summary table for reasons paper
eststo clear
*Preferred model
eststo: quietly reg lindirect licp_total if year > 2009 & outlier_nn==0 , robust
*Draft decision model (length of circuit, energy, density)
eststo: quietly reg lindirect lcircuit_length_total lelectricity_supplied icp_km if year > 2009 & outlier_nn==0, robust 
*Same spec as network opex
eststo: quietly reg lindirect lcircuit_length_total licp_total if year > 2009 & outlier_nn==0, robust 
*Number of ICPs and energy supplied
eststo: quietly reg lindirect licp_total lelectricity_supplied if year > 2009 & outlier_nn==0, robust 
*All scale drivers
eststo: quietly reg lindirect licp_total lcircuit_length_total lelectricity_supplied if year > 2009 & outlier_nn==0 , robust
estout using " non-network opex decision.xls", cells(b(star fmt(%9.3f))) stats(r2_a aic bic F N, fmt(%9.2f) )   starlevels(* 0.10 ** 0.05 *** 0.01) replace



capture log close

